( cd usr/share/java ; rm -rf rhino.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/rhino.jar rhino.jar )
( cd usr/share/java ; rm -rf rhino-1.7.7.1.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/rhino-1.7.7.1.jar rhino-1.7.7.1.jar )
( cd usr/share/ant/lib ; rm -rf rhino.jar )
( cd usr/share/ant/lib ; ln -sf rhino-1.7.7.1.jar rhino.jar )
